@@ -545,7 +545,8 @@ class Message(BASE, ModelBase):
     updated_at = Column("updated_at", DateTime, default=datetime.datetime.utcnow, onupdate=datetime.datetime.utcnow)
     msg_content = Column(JSON())
 
-    _table_args = (PrimaryKeyConstraint('msg_id', name='MESSAGES_PK'))
+    _table_args = (PrimaryKeyConstraint('msg_id', name='MESSAGES_PK'),
+                   Index('MESSAGES_TYPE_ST_IDX', 'msg_type', 'status', 'destination', 'request_id'))
 
 
 def register_models(engine):
