@@ -24,6 +24,7 @@ from idds.rest.v1 import cacher
 from idds.rest.v1 import hyperparameteropt
 from idds.rest.v1 import logs
 from idds.rest.v1 import monitor
+from idds.rest.v1 import messages
 
 
 class LoggingMiddleware(object):
@@ -57,6 +58,7 @@ def get_blueprints():
     bps.append(hyperparameteropt.get_blueprint())
     bps.append(logs.get_blueprint())
     bps.append(monitor.get_blueprint())
+    bps.append(messages.get_blueprint())
     return bps
 
 
